#
# spec file for package python-opentelemetry-instrumentation
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-instrumentation
Version:        0.48b0
Release:        1.2
Summary:        Instrumentation Tools & Auto Instrumentation for OpenTelemetry Python
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python/tree/main/opentelemetry-instrumentation
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-instrumentation/opentelemetry_instrumentation-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module opentelemetry-api >= 1.4}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wrapt >= 1.0.0}
# /SECTION
BuildRequires:  fdupes
Requires(post): update-alternatives
Requires(postun): update-alternatives
Requires:       python-opentelemetry-api >= 1.4
Requires:       python-wrapt >= 1.0.0
BuildArch:      noarch
%python_subpackages

%description
Instrumentation Tools & Auto Instrumentation for OpenTelemetry Python

%prep
%setup -q -n opentelemetry_instrumentation-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/opentelemetry-instrument
%python_clone -a %{buildroot}%{_bindir}/opentelemetry-bootstrap
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Tests disabled because they're not shipped with the sources
#%%check
#%%pytest

%post
%python_install_alternative opentelemetry-instrument opentelemetry-bootstrap

%postun
%python_uninstall_alternative opentelemetry-instrument

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/opentelemetry-instrument
%python_alternative %{_bindir}/opentelemetry-bootstrap
%{python_sitelib}/opentelemetry/instrumentation
%{python_sitelib}/opentelemetry_instrumentation-%{version}.dist-info

%changelog
* Fri Aug 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.48b0
  * `opentelemetry-instrumentation-kafka-python` Instrument temporary fork,
    kafka-python-ng inside kafka-python's instrumentation (#2537)
  * `opentelemetry-bootstrap` Remove `opentelemetry-instrumentation-aws-lambda`
    from the defaults instrumentations (#2786)
  * `opentelemetry-instrumentation-httpx` fix handling of async hooks (#2823)
  * `opentelemetry-instrumentation-system-metrics` fix `process.runtime.cpu.utilization`
    values to be shown in range of 0 to 1 (#2812)
  * `opentelemetry-instrumentation-fastapi` fix `fastapi` auto-instrumentation by removing
    `fastapi-slim` support, `fastapi-slim` itself is discontinued from maintainers (#2783)
  * `opentelemetry-instrumentation-aws-lambda` Avoid exception when a handler is not present. (#2750)
  * `opentelemetry-instrumentation-django` Fix regression * `http.target`
    re-added back to old semconv duration metrics (#2746)
  * `opentelemetry-instrumentation-asgi` do not set `url.full` attribute for server spans (#2735)
  * `opentelemetry-instrumentation-grpc` Fixes the issue with the gRPC instrumentation
    not working with the 1.63.0 and higher version of gRPC (#2483)
  * `opentelemetry-instrumentation-aws-lambda` Fixing w3c baggage support (#2589)
  * `opentelemetry-instrumentation-celery` propagates baggage (#2385)
  * `opentelemetry-instrumentation-asyncio` Fixes async generator
    coroutines not being awaited (#2792)
  * `opentelemetry-instrumentation-tornado` Handle http client exception
    and record exception info into span (#2563)
  * `opentelemetry-instrumentation` fix `http.host` new http semantic
    convention mapping to depend on `kind` of span (#2814)
- for changes between 0.25b2 and 0.48b0 see upstream CHANGELOG.md
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Limit Python files matched in %%files section
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Update BuildRequires from pyproject.toml
* Fri Nov  5 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.25b2
